/**
 * YUI Panel basierter Vorschalgsnotifier
 */
SeeMeYUI.use('panel', 'node', function (Y) {

    FullScreenPromptNotifier = function () {

        this.currentTopicPanelNode = Y.Node.create('<div>' +
            '	<div class="yui3-widget-bd">' +
            '		<div id="current-topic-prompt-notification-text">Neuer Prompt!</div>' +
            '	</div>' +
            '</div>'
        );

        this.otherTopicPanelNode = Y.Node.create('<div>' +
            '	<div class="yui3-widget-bd">' +
            '		<div id="other-topic-prompt-notification-text">Neuer Prompt!</div>' +
            '	</div>' +
            '</div>'
        );

        this.currentTopicPanel = new Y.Panel({
            srcNode: this.currentTopicPanelNode,
            centered: true,
            visible: false,
            modal: true,
            zIndex: 5,
            headerContent: "A new Prompt is available ..."
        });

        this.currentTopicPanel.addButton({
            value: "Show",
            action: Y.bind(this.doShowPrompt, this),
            section: Y.WidgetStdMod.FOOTER
        });

        this.otherTopicPanel = new Y.Panel({
            srcNode: this.otherTopicPanelNode,
            centered: true,
            visible: false,
            modal: true,
            zIndex: 5,
            headerContent: "A new Prompt is available ..."
        });

        this.otherTopicPanel.addButton({
            value: "Show",
            action: Y.bind(this.doShowPrompt, this),
            section: Y.WidgetStdMod.FOOTER
        });

        this.otherTopicPanel.addButton({
            value: "Ignore",
            action: Y.bind(this.doIgnorePrompt, this),
            section: Y.WidgetStdMod.FOOTER
        });

        this.currentTopicPanel.render();
        this.otherTopicPanel.render();

        this.activePanel = null;
    };

    FullScreenPromptNotifier.prototype = {

        setFacilitatorClient: function (facilitatorClient) {
            this.facilitatorClient = facilitatorClient;
        },

        notify: function (topicController, topic, prompt) {
            var currentTopic = topicController.getCurrentTopic(),
                data = {
                    topicController: topicController,
                    topic: topic,
                    prompt: prompt
                };

            this.data = data;
            if (currentTopic && (currentTopic == topic)) {
                this.showPromptInCurrentTopic();
            } else {
                this.showPromptInTopic();
            }
        },

        doShowPrompt: function (e) {
            e.preventDefault();

            this.clearActivePanel();
            if (this.data.prompt) {
                this.data.topicController.showPrompt(this.data.prompt);
            } else {
                this.data.topicController.openTopic(this.data.topic);
            }
        },

        doIgnorePrompt: function (e) {
            e.preventDefault();

            this.clearActivePanel();
        },

        showPromptInCurrentTopic: function () {
            var text = "<div style='font-style: italic;'>" + this.data.prompt.text + "</div>";
            var promptNotificationText = Y.one("#current-topic-prompt-notification-text");
            promptNotificationText.set('innerHTML', text);

            this.showPanel(this.currentTopicPanel);
        },

        showPromptInTopic: function () {

            var text = "<div><span style='font-weight: bold;'>" + this.data.topic.getText() + "</span>:</div>";
            if (this.data.prompt) {
                text += "<div style='font-style: italic;'>" + this.data.prompt.text + "</div>";
            }

            var promptNotificationText = Y.one("#other-topic-prompt-notification-text");
            promptNotificationText.set('innerHTML', text);

            this.showPanel(this.otherTopicPanel);
        },

        showPanel: function (panel) {
            this.clearActivePanel();
            this.activePanel = panel;
            panel.show();
        },

        clearActivePanel: function () {
            if (this.activePanel != null) {
                this.activePanel.hide();
            }
            this.activePanel = null;
        }
    };
});
