SeeMeYUI.use("cookie", "idle-timer", function (Y) {

    var GRACE_PERIOD = 10000; // 10 Sekunden

    SessionController = function () {
        var ci = Y.Cookie.get("client");
        if (ci == null) {
            ci = new UUID().valueOf();
            Y.Cookie.set("client", ci);
        }

        this.promptNotifier = new FullScreenPromptNotifier();

        Y.IdleTimer.subscribe("idle", this.showSuggestion, this);
        Y.IdleTimer.subscribe("active", this.clearSuggestion, this);
        Y.IdleTimer.start(GRACE_PERIOD);

        Y.one("#card-send-comment").on("click", this.sendComment, this);
        
        this.initializeTopicController();
    };

    SessionController.prototype = {
        getParticipantId: function () {
            return this.participantId;
        },

        getCurrentSession: function () {
            return this.currentSession;
        },

        start: function () {
        },

        stop: function () {
        },

        removeCurrentTopicController: function () {
            if (this.sessionUpdater) {
                this.sessionUpdater.stop();
                delete this.sessionUpdater;
            }
            if (this.topicController) {
                this.topicController.stop();
                delete this.topicController;
            }
        },



        initializeTopicController: function () {
            this.topicController = new TopicController(this);
            this.sessionUpdater = new SessionUpdater(this);

            this.topicController.start();
            this.sessionUpdater.start();
        },


        updateSession: function (session) {
            this.currentSessionData = session;
            this.topicController.update(session.topics);

            if (session.state == 'ACTIVE') {
                this.topicController.show();
                if (session.current) {
                    console.log("current", session.current);
                    this.topicController.setCurrentTopicView(session.current);
                }
                if (session.suggestion) {
                    console.log("suggestion", session.suggestion);
                    this.suggestion = session.suggestion;
                    this.showSuggestion();
                }
                Y.one("#post-editor-container").hide();
            } else if (session.state == 'REVIEW') {
                this.topicController.stop();
                Y.one("#post-editor-container").show();
                this.requestComment(session.commentRequest);
            } else {
                this.topicController.stop();
                Y.one("#post-editor-container").hide();
            }

        },

        requestComment: function (request) {
            if (!request) {
                Y.one("#no-comment-request").show();
                Y.one("#editor-container").hide();
                Y.one("#card-info").hide();
            } else {
                if (this.commentRequest && (this.commentRequest.cardId == request.cardId)) {
                    // wiederholte Anfrage
                    return;
                }

                if (request.commentText) {
                    Y.one("#card-comment").set("value", request.commentText);
                } else {
                    Y.one("#card-comment").set("value", "");
                }

                Y.one("#card-text").set("innerHTML", request.text);
                Y.one("#card-topic").set("innerHTML", request.topic);
                Y.one("#card-id").set("value", request.cardId);

                Y.one("#no-comment-request").hide();
                Y.one("#editor-container").show();
                Y.one("#card-info").show();
            }
            this.commentRequest = request;
        },

        sendComment: function (e) {
            e.halt(true);
            if (!this.commentRequest) {
                return;
            }

            var sessionId = this.getCurrentSession().id,
                topicId = this.commentRequest.topicId,
                cardId = this.commentRequest.cardId,
                text = Y.one("#card-comment").get("value");

            sendUpdateComment(sessionId, topicId, cardId, text, this.getParticipantId());

            Y.one("#card-comment").set("value", "");
            Y.one("#no-comment-request").hide();
            Y.one("#editor-container").show();
            Y.one("#card-info").show();
        },

        /**
         * Aktualisiert den aktuellen Prompt des Users. Ggfs. wird nur ein Hinweis angezeigt, wenn der Benutzer gerade
         * einen anderen Prompt sieht.
         * @param data
         */
        makeSuggestion: function (data) {
            if (!data) {
                return;
            }

            var suggestedTopic; // der vorgeschlagene Topic. Kann vom aktuellen Topic abweichen
            if (data.topicId) {
                suggestedTopic = this.topicController.findTopic(data.topicId);
            }

            var suggestedPrompt; // der vorgeschlagene Prompt
            if (data.promptId) {
                if (!suggestedTopic) {
                    suggestedTopic = this.topicController.findTopicForPrompt(data.promptId);
                }

                if (!suggestedTopic) {
                    console.log("Vorgeschlagener Topic nicht gefunden!");
                    return;
                }

                suggestedPrompt = suggestedTopic.getPromptById(data.promptId);
            }

            if (!suggestedPrompt) {
                console.log("Vorgeschlagener Prompt nicht gefunden");
                return;
            }

            var currentTopic = this.topicController.getCurrentTopic();
            if (currentTopic && (currentTopic == suggestedTopic) && (currentTopic.getCurrentPrompt() == suggestedPrompt)) {
                console.log("suggested prompt wird schon angezeigt");
                return;
            }

            this.promptNotifier.notify(this.topicController, suggestedTopic, suggestedPrompt);
        },

        showNewPromptAlert: function () {
            alert("New Prompt");
        },

        showSuggestion: function () {
            if (!Y.IdleTimer.isIdle()) {
                return;
            }
            if (!this.suggestion) {
                return;
            }

            var suggestion = this.suggestion;
            delete this.suggestion;
            this.makeSuggestion(suggestion);
        },

        clearSuggestion: function () {
        }
    };
});